@@ -3,7 +3,7 @@ from flatblocks.models import FlatBlock
  
 class FlatBlockAdmin(admin.ModelAdmin):
     ordering = ['slug',]
-    list_display = ('slug', 'header', 'content')
+    list_display = ('slug', 'header')
     search_fields = ('slug', 'header', 'content')
 
-admin.site.register(FlatBlock, FlatBlockAdmin)
\ No newline at end of file
+admin.site.register(FlatBlock, FlatBlockAdmin)
